# xlviews

[![PyPI Version][pypi-v-image]][pypi-v-link]
[![Python Version][python-v-image]][python-v-link]
[![Build Status][GHAction-image]][GHAction-link]
[![Coverage Status][codecov-image]][codecov-link]

## Installation

```bash
pip install xlviews
```

## Examples

### `SheetFrame`

```bash
python -m xlviews.testing.sheet_frame.base
```

![SheetFrame](./docs/images/sheet_frame.png)

### `StatsFrame`

```bash
python -m xlviews.testing.stats_frame
```

![StatsFrame](./docs/images/stats_frame.png)

### `HeatFrame`

```bash
python -m xlviews.testing.heat_frame.base
```

![HeatFrame](./docs/images/heat_frame.png)

<!-- Badges -->
[pypi-v-image]: https://img.shields.io/pypi/v/xlviews.svg
[pypi-v-link]: https://pypi.org/project/xlviews/
[python-v-image]: https://img.shields.io/pypi/pyversions/xlviews.svg
[python-v-link]: https://pypi.org/project/xlviews
[GHAction-image]: https://github.com/daizutabi/xlviews/actions/workflows/ci.yaml/badge.svg?branch=main&event=push
[GHAction-link]: https://github.com/daizutabi/xlviews/actions?query=event%3Apush+branch%3Amain
[codecov-image]: https://codecov.io/github/daizutabi/xlviews/coverage.svg?branch=main
[codecov-link]: https://codecov.io/github/daizutabi/xlviews?branch=main
